<?php

use App\Http\Controllers\HomeController;
use App\Http\Controllers\User\BookingController;
use App\Http\Controllers\User\DashboardController;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/


Route::get('/', [HomeController::class, 'index'])->name('welcome');

// Route::get('/', [DashboardController::class, 'index'])->name('dashboard');

Route::get('/about', [HomeController::class, 'about'])->name('about');
Route::get('/search', [HomeController::class, 'search'])->name('search');
Route::get('/place/details/{id}', [HomeController::class, 'placeDdetails'])->name('place.details');
Route::get('/package/details/{id}', [HomeController::class, 'packageDetails'])->name('package.details');
Route::get('/place-list', [HomeController::class, 'allPlace'])->name('all.place');
Route::get('/package-list', [HomeController::class, 'allPackage'])->name('all.package');
Route::get('/district/{id}', [HomeController::class, 'districtWisePlace'])->name('district.wise.place');
Route::get('/placetype/{id}', [HomeController::class, 'placetypeWisePlace'])->name('placetype.wise.place');

Route::get('/package/booking/{id}', [HomeController::class, 'packageBooking'])->name('package.booking');
Route::get('/package/booking', [HomeController::class, 'storeBookingRequest'])->name('store.package.booking');


Auth::routes(['verify' => true]);

// Route::get('/home', 'HomeController::class, 'index')->name('home');



// Route::group([
//     'as' => 'admin.',
//     'prefix' => 'admin',
//     // 'namespace' => 'Admin',
//     'middleware' => [
//         'auth', 'admin', 'verified'
//     ]
// ], function () {

Route::prefix('admin')->middleware('auth', 'admin')->group(
    function () {
        Route::get('dashboard', 'App\Http\Controllers\Admin\DashboardController@index')->name('admin.dashboard');
        Route::get('profile-info', 'App\Http\Controllers\Admin\DashboardController@showProfile')->name('admin.profile.show');
        Route::get('profile-info/edit/{id}', 'App\Http\Controllers\Admin\DashboardController@editProfile')->name('admin.profile.edit');
        Route::post('profile-info/update', 'App\Http\Controllers\Admin\DashboardController@updateProfile')->name('admin.profile.update');

        Route::resource('faq', 'App\Http\Controllers\Admin\ProductFaqController', ['as' => 'admin']);


        Route::resource('district', 'App\Http\Controllers\Admin\DistrictController', ['as' => 'admin']);
        Route::resource('type', 'App\Http\Controllers\Admin\TypeController', ['as' => 'admin']);
        Route::resource('place', 'App\Http\Controllers\Admin\PlaceController', ['as' => 'admin']);
        Route::resource('about', 'App\Http\Controllers\Admin\AboutController', ['as' => 'admin']);
        Route::resource('guide', 'App\Http\Controllers\Admin\GuideController', ['as' => 'admin']);
        Route::resource('users', 'App\Http\Controllers\Admin\UsersController', ['as' => 'admin']);
        Route::resource('package', 'App\Http\Controllers\Admin\PackageController', ['as' => 'admin']);
        Route::get('list', 'App\Http\Controllers\Admin\UsersController@adminList')->name('admin.list');


        Route::get('booking-request/list', 'App\Http\Controllers\Admin\BookingController@pendingBookingList')->name('admin.pending.booking');
        Route::post('booking-request/approve/{id}', 'App\Http\Controllers\Admin\BookingController@bookingApprove')->name('admin.booking.approve');
        Route::post('booking-request/remove/{id}', 'App\Http\Controllers\Admin\BookingController@bookingRemoveByAdmin')->name('admin.booking.remove');
        Route::get('running/packages/', 'App\Http\Controllers\Admin\BookingController@runningPackage')->name('admin.package.running');
        Route::post('running/package/complete/{id}', 'App\Http\Controllers\Admin\BookingController@runningPackageComplete')->name('admin.package.running.complete');
        Route::get('tour-history/list', 'App\Http\Controllers\Admin\BookingController@tourHistory')->name('admin.tour.history');
    }
);

// Route::group([
//     'as' => 'user.',
//     'prefix' => 'user',
//     // 'namespace' => 'User',
//     'middleware' => [
//         'auth', 'user', 'verified'
//     ]
// ], function () {
Route::prefix('user')->middleware('auth', 'user', 'verified')->group(
    function () {

        Route::get('dashboard', [DashboardController::class, 'index'])->name('user.dashboard');

        Route::get('profile-info', [DashboardController::class, 'showProfile'])->name('user.profile.show');
        Route::get('profile-info/edit/{id}', [DashboardController::class, 'editProfile'])->name('user.profile.edit');
        Route::post('profile-info/update', [DashboardController::class, 'updateProfile'])->name('user.profile.update');

        Route::get('districts', [DashboardController::class, 'getDistrict'])->name('user.district');
        Route::get('placetypes', [DashboardController::class, 'getPlaceType'])->name('user.placetype');

        Route::get('places', [DashboardController::class, 'getPlaces'])->name('user.place');
        Route::get('places/{id}', [DashboardController::class, 'getPlaceDetails'])->name('user.place.show');

        Route::get('guides', [DashboardController::class, 'getGuides'])->name('user.guide');
        Route::get('guide/{id}', [DashboardController::class, 'getGuideDetails'])->name('user.guide.show');

        Route::get('packages', [DashboardController::class, 'getPackage'])->name('user.package');
        Route::get('packages/{id}', [DashboardController::class, 'getPackageDetails'])->name('user.package.show');


        Route::get('tour-history/list', [BookingController::class, 'tourHistory'])->name('user.tour.history');
        Route::get('booking-request/list', [BookingController::class, 'pendingBookingList'])->name('user.pending.booking');
        Route::post('booking-request/cancel/{id}', [BookingController::class, 'canceLBookingRequest'])->name('user.booking.cancel');
    }
);



View::composer('layouts.frontend.inc.footer', function ($view) {
    $placetypes = App\Placetype::all();
    $view->with('placetypes', $placetypes);
});
